import type { Editor } from 'mem-fs-editor';
import { UI5Config } from '@sap-ux/ui5-config';
/**
 * Get path to webapp.
 *
 * @param appRoot - root to the application
 * @param [memFs] - optional mem-fs editor instance
 * @returns - path to webapp folder
 */
export declare function getWebappPath(appRoot: string, memFs?: Editor): Promise<string>;
/**
 * Checks if UI5 config yaml file exists and returns its content.
 *
 * @param projectRoot - path to project root
 * @param fileName - name of yaml file to be read
 * @param [memFs] - optional mem-fs editor instance
 * @param options - options
 * @param [options.validateSchema] - optional flag to validate the schema of the yaml file
 * @returns {UI5Config} UI5 config file in yaml format
 * @throws {Error} if file is not found
 */
export declare function readUi5Yaml(projectRoot: string, fileName: string, memFs?: Editor, options?: {
    validateSchema: boolean;
}): Promise<UI5Config>;
/**
 * Scans the project directory for ui5 configuration yaml files.
 *
 * @param projectRoot - path to project root, where ui5 configuration y*ml files are located
 * @param [memFs] - optional mem-fs editor instance
 * @returns list of valid and invalid UI5 configuration yaml file names
 * @throws {Error} if an error occurs while reading files from projectRoot
 */
export declare function getAllUi5YamlFileNames(projectRoot: string, memFs?: Editor): Promise<string[]>;
//# sourceMappingURL=ui5-config.d.ts.map